@@ -1,21 +1,30 @@
 package HTML::FormFu::Deflator::FormatNumber;
+{
+  $HTML::FormFu::Deflator::FormatNumber::VERSION = '1.00';
+}
 
-use strict;
-use base 'HTML::FormFu::Deflator';
+use Moose;
+use MooseX::Attribute::Chained;
+extends 'HTML::FormFu::Deflator';
 
 use Number::Format;
 use POSIX qw( setlocale LC_NUMERIC );
 
-__PACKAGE__->mk_item_accessors(qw( precision trailing_zeroes ));
+has precision => (
+    is      => 'rw',
+    default => 2,
+    lazy    => 1,
+    isa     => 'Int',
+    traits  => ['Chained'],
+);
 
-sub new {
-    my $self = shift->next::method(@_);
-
-    $self->precision(2);
-    $self->trailing_zeroes(0);
-
-    return $self;
-}
+has trailing_zeroes => (
+    is      => 'rw',
+    default => 0,
+    lazy    => 1,
+    isa     => 'Int',
+    traits  => ['Chained'],
+);
 
 sub deflator {
     my ( $self, $value ) = @_;
@@ -42,6 +51,8 @@ sub deflator {
     return $value;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
