@@ -1,6 +1,10 @@
 package HTML::FormFu::Role::Populate;
+{
+  $HTML::FormFu::Role::Populate::VERSION = '1.00';
+}
 use Moose::Role;
 
+use Scalar::Util qw( reftype );
 use Carp qw( croak );
 
 after BUILD => sub {
@@ -9,9 +13,12 @@ after BUILD => sub {
     $args ||= {};
 
     # get args handled by Moose so they aren't set twice
-    my %init_args = map { $_->{init_arg} => 1 } $self->meta->get_all_attributes;
+    my %init_args =
+        map { $_->{init_arg} => 1 }
+        grep { defined $_->{init_arg} }
+            $self->meta->get_all_attributes;
 
-# remove defaults set in HTML::FormFu::BUILD because they need to be set for a third time
+    # remove defaults set in HTML::FormFu::BUILD because they need to be set for a third time
     delete @init_args{ keys %{$HTML::FormFu::build_defaults} };
     my %args
         = map { $_ => $args->{$_} } grep { !exists $init_args{$_} } keys %$args;
@@ -23,6 +30,9 @@ after BUILD => sub {
 sub populate {
     my ( $self, $arg_ref ) = @_;
 
+    croak "argument to populate() must be a hash-ref"
+        if reftype($arg_ref) ne 'HASH';
+
     # shallow clone the args so we don't stomp on them
     my %args = %$arg_ref;
 
@@ -33,11 +43,14 @@ sub populate {
         $self->element_defaults( delete $args{element_defaults} );
     }
 
-    # notes for @keys...
+    # handle any 'roles' first
+    my $roles = delete $args{roles};
+
+    # notes for @defer_keys...
     # 'options', 'values', 'value_range' is for _Group elements,
     # to ensure any 'empty_first' value gets set first
 
-    my @keys = qw(
+    my @defer_keys = qw(
         default_args
         auto_fieldset
         load_config_file
@@ -57,15 +70,19 @@ sub populate {
     );
 
     my %defer;
-    for (@keys) {
+    for (@defer_keys) {
         $defer{$_} = delete $args{$_} if exists $args{$_};
     }
 
     eval {
+        if ( $roles ) {
+            $self->roles( $roles );
+        }
+
         map { $self->$_( delete $args{$_} ) } keys %args;
 
         map      { $self->$_( $defer{$_} ) }
-            grep { exists $defer{$_} } @keys;
+            grep { exists $defer{$_} } @defer_keys;
     };
     croak $@ if $@;
 
